@@ -1,8 +1,9 @@
 """DataSet TransLation (DSTL) provides utilities to translate annotated natural language data from one language to another."""
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
-from .translate import TransformersMarianTranslator, translate_ner_batch
+from .translate import TransformersMarianTranslator
+from .translate.core import translate_ner_batch
 
 try:
     # This needs to be imported in order for the entry points to be loaded
